@@ -10,11 +10,15 @@ use Types::Standard 'HashRef';
 use Data::Object 'deduce_deep', 'detract_deep';
 
 with 'Data::Object::Role::Hash';
+with 'Data::Object::Role::Defined';
+with 'Data::Object::Role::Collection';
 with 'Data::Object::Role::Detract';
+with 'Data::Object::Role::Keyed';
 with 'Data::Object::Role::Output';
+with 'Data::Object::Role::Ref';
 with 'Data::Object::Role::Values';
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 sub new {
     my $class = shift;
@@ -216,7 +220,7 @@ Data::Object::Hash - A Hash Object for Perl 5
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
