@@ -11,10 +11,12 @@ use Data::Object 'deduce_deep', 'detract_deep';
 
 with 'Data::Object::Role::Constructor';
 with 'Data::Object::Role::Scalar';
+with 'Data::Object::Role::Defined';
 with 'Data::Object::Role::Detract';
 with 'Data::Object::Role::Output';
+with 'Data::Object::Role::Ref';
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 around 'and' => sub {
     my ($orig, $self, @args) = @_;
@@ -62,7 +64,7 @@ Data::Object::Scalar - A Scalar Object for Perl 5
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
